@@ -6,7 +6,7 @@ use strict;
 use 5.010000;
 
 use Exporter qw( import );
-our @EXPORT_OK = qw( read_config_file set_options );
+our @EXPORT_OK = qw( read_config_file set_options sort_order_list );
 
 use File::Spec::Functions qw( catfile );
 use File::Temp            qw();
@@ -16,6 +16,7 @@ use Pod::Usage            qw( pod2usage );
 
 use File::Which            qw( which );
 use IPC::System::Simple    qw( capture );
+use List::MoreUtils        qw( first_index );
 use Term::Choose           qw( choose );
 use Term::ReadLine::Simple qw();
 use Text::LineFold         qw();
@@ -36,6 +37,7 @@ sub _menus {
             [ 'group_quality',   "- Quality"    ],
             [ 'group_download',  "- Download"   ],
             [ 'group_history',   "- History"    ],
+            [ 'group_list_menu', "- List menu"  ],
             [ 'group_output',    "- Appearance" ],
             [ 'list_extractors', "  Extractors" ],
         ],
@@ -52,8 +54,7 @@ sub _menus {
         group_history => [
             [ 'log_info',             "- Logging"         ],
             [ 'max_channels',         "- Channel history" ],
-            [ 'channel_by_timestamp', "- Channel sort"    ],
-            [ 'list_size_idx',        "- Size video list"  ],
+            [ 'channel_by_timestamp', "- History sort"    ],
         ],
         group_directory => [
             [ 'video_dir',     "- Main video directory" ],
@@ -64,10 +65,14 @@ sub _menus {
             [ 'max_len_f_name',           "- Max filename length" ],
             [ 'upload_date_is_file_date', "- File timestamp"      ],
         ],
+        group_list_menu => [
+            [ 'list_size_idx',   "- Size video list" ],
+            [ 'sort_item',       "- Sort order"      ],
+            [ 'show_view_count', "- Show view count" ],
+        ],
         group_output => [
-            [ 'max_info_width', "- Max info width" ],
-            [ 'kb_sec_len',     "- Digits 'k/s'"   ],
-            [ 'new_first',      "- Sort order"     ],
+            [ 'max_info_width',  "- Max info width"  ],
+            [ 'kb_sec_len',      "- Digits 'k/s'"    ],
         ],
     };
     return $menus;
@@ -264,10 +269,10 @@ sub set_options {
                 _opt_choose_from_list( $opt, $choice, $prompt, $list );
             }
             elsif ( $choice eq "list_size_idx" ) {
-                my $prompt = 'Channel/Playlist - Show';
+                my $prompt = 'Channel/Playlist';
                 my $list = [
-                    'all videos',
-                    'the latest 50 videos',
+                    'Show all videos',
+                    'Show only the latest 50 videos',
                 ];
                 _opt_choose_from_list( $opt, $choice, $prompt, $list );
             }
@@ -292,9 +297,16 @@ sub set_options {
                 my $prompt = 'Change the file timestamps to the upload date';
                 _opt_yes_no( $opt, $choice, $prompt );
             }
-            elsif ( $choice eq "new_first" ) {
-                my $prompt = 'Latest videos on top of the list';
-                _opt_yes_no( $opt, $choice, $prompt );
+            elsif ( $choice eq "sort_item" ) {
+                sort_order_list( $opt );
+            }
+            elsif ( $choice eq "show_view_count" ) {
+                my $prompt = 'Show view count in channel/playlist menu';
+                my $list = [
+                    'If ordered by view count',
+                    'Always',
+                ];
+                _opt_choose_from_list( $opt, $choice, $prompt, $list );
             }
             else { die $choice }
         }
@@ -396,6 +408,41 @@ sub _opt_choose_from_list {
 }
 
 
+sub sort_order_list {
+    my ( $opt ) = @_;
+    my $sort_items = [
+        { key => 'upload_date',    prompt => '"Upload date"' },
+        { key => 'title',          prompt => '"Title"'       },
+        { key => 'view_count_raw', prompt => '"View count"'  },
+        { key => 'duration',       prompt => '"Duration"'    },
+    ];
+    my $first_index = first_index { $_->{key} eq $opt->{sort_item} } @$sort_items;
+    my $prompt = sprintf 'Sort order ("%s"):', $sort_items->[$first_index]{prompt};
+    my @pre = ( undef );
+    my $choices = [ @pre, map( $_->{prompt}, @$sort_items ) ];
+    my $idx = choose (
+        $choices,
+        { prompt => $prompt, layout => 1, index => 1, undef => '<<' }
+    );
+    if ( ! defined $idx || ! defined $choices->[$idx] ) {
+        return;
+    }
+    $opt->{change}++;
+    $idx -= @pre;
+    $opt->{sort_item} = $sort_items->[$idx]{key};
+    my $order_prompt = sprintf '%s:', $sort_items->[$idx]{prompt};
+    my $order = choose (
+        [ @pre, 'Desc', 'Asc' ],
+        { prompt => $order_prompt, layout => 1, undef => '<<' }
+    );
+    if ( ! defined $order ) {
+        return;
+    }
+    $opt->{sort_order} = $order;
+    return;
+}
+
+
 sub _write_config_file {
     my ( $opt, $file, @keys ) = @_;
     return if ! $opt->{change};
