@@ -6,10 +6,11 @@ use strict;
 use 5.010000;
 
 use Exporter qw( import );
-our @EXPORT_OK = qw( wrapper_get get_new_video_url get_download_info_as_json );
+our @EXPORT_OK = qw( get_yt_download_info_as_h_ref get_new_video_url get_download_info_as_json );
 
 use File::Which         qw( which );
 use IPC::System::Simple qw( capture );
+use JSON                qw( decode_json );
 use LWP::UserAgent      qw();
 use Term::ANSIScreen    qw( :screen );
 use Try::Tiny           qw( try catch );
@@ -20,7 +21,7 @@ use App::YTDL::Helper qw( HIDE_CURSOR SHOW_CURSOR );
 
 
 
-sub wrapper_get {
+sub get_yt_download_info_as_h_ref {
     my ( $opt, $url ) = @_;
     my $show_progress = 1;
     my $ua = LWP::UserAgent->new(
@@ -28,13 +29,15 @@ sub wrapper_get {
         timeout       => $opt->{timeout},
         show_progress => $show_progress
     );
-    my $res;
+    my $h_ref;
     my $count = 1;
     RETRY: while ( 1 ) {
         my $not_ok;
         try {
-            $res = $ua->get( $url );
+            my $res = $ua->get( $url );
             die $res->status_line, ': ', $url if ! $res->is_success;
+            my $json = $res->decoded_content;
+            $h_ref = decode_json( $json );
         }
         catch {
             if ( $count > $opt->{retries} ) {
@@ -46,7 +49,7 @@ sub wrapper_get {
             sleep $opt->{retries} * 3;
         };
         next RETRY if $not_ok;
-        return $res;
+        return $h_ref;
     }
 }
 
