@@ -60,12 +60,12 @@ sub add_entry_to_info_hash {
     if ( defined $type && $type eq 'PL' ) {
         $info->{$video_id}{playlist_id} = $list_id;
     }
-    _prepare_info_hash( $info, $video_id );
+    _prepare_info_hash( $opt, $info, $video_id );
 }
 
 
 sub json_to_hash {
-    my ( $json, $tmp ) = @_;
+    my ( $opt, $tmp, $json ) = @_;
     my $h_ref = decode_json( $json );
     my $formats  = {};
     for my $format ( @{$h_ref->{formats}} ) {
@@ -80,7 +80,7 @@ sub json_to_hash {
     my $video_id = $h_ref->{id} // $h_ref->{title};
     $tmp->{$video_id}{video_id} = $video_id;
     my @keys = ( qw( uploader uploader_id description format_id dislike_count dislike_count
-                     duration extractor extractor_key like_coun playlist_id title upload_date view_count ) );
+                     duration extractor extractor_key like_count playlist_id title upload_date view_count ) );
                      # age_limit annotations fulltitle playlist stitle categories
     for my $key ( @keys ) {
         if ( defined $h_ref->{$key} ) {
@@ -91,13 +91,13 @@ sub json_to_hash {
             $tmp->{$video_id}{upload_date} = $1 . '-' . $2 . '-' . $3;
     }
     $tmp->{$video_id}{fmt_to_info} = $formats;
-    _prepare_info_hash( $tmp, $video_id );
+    _prepare_info_hash( $opt, $tmp, $video_id );
     return;
 }
 
 
 sub _prepare_info_hash {
-    my ( $info, $video_id ) = @_;
+    my ( $opt, $info, $video_id ) = @_;
     if ( $info->{$video_id}{duration} =~ /^[0-9]+\z/ ) {
         $info->{$video_id}{duration} = sec_to_time( $info->{$video_id}{duration}, 1 );
     }
@@ -114,7 +114,11 @@ sub _prepare_info_hash {
         $info->{$video_id}{raters} = insert_sep( $info->{$video_id}{raters} );
     }
     if ( $info->{$video_id}{view_count} ) {
+        $info->{$video_id}{view_count_raw} = $info->{$video_id}{view_count} // 0;
         $info->{$video_id}{view_count} = insert_sep( $info->{$video_id}{view_count} );
+        if ( length $info->{$video_id}{view_count} > $opt->{view_count_length} ) {
+            $opt->{view_count_length} = length $info->{$video_id}{view_count}; #
+        }
     }
     $info->{$video_id}{uploader}      //= $info->{$video_id}{uploader_id};
     $info->{$video_id}{extractor}     //= $info->{$video_id}{extractor_key};
